@@ -182,7 +182,10 @@ class TaskState(object):
             self.parent.printer(line)
             if not i.last:
                 self.parent.printer('\n')
-        self.parent.printer.flush()
+        try:
+            self.parent.printer.flush()
+        except IOError:
+            pass
 
     def printERROR(self, message):
         self.printMessage(Colors.RED, message)
